@@ -10,7 +10,7 @@ from .cgeneric import ContextSensitiveScanner
 from .generic import GenericScanner
 from .cltoken import Token
 import re
-from stsci.tools import irafutils
+from .tools import irafutils
 from . import pyrafglobals
 
 # contexts for scanner
@@ -268,6 +268,12 @@ class _StartScanner(_LaxScanner, _StrictStartScanner):
 
 class _CommandScanner_1(_BasicScanner_1):
 
+    def t_lbracket(self, s, m, parent):
+        r'\['
+        parent.addToken(type=s)
+        # push to compute mode
+        parent.current.append(_COMPUTE_MODE)
+
     def t_string(self, s, m, parent):
         r'[^ \t\n()\\;{}&]+(\\(.|\n)[^ \t\n()\\;{}&]*)*'
         # What other characters are forbidden in unquoted strings?
@@ -284,12 +290,6 @@ class _CommandScanner_1(_BasicScanner_1):
         parent.addToken(type='STRING', attr=s)
         parent.lineno = parent.lineno + nline
 
-    def t_lbracket(self, s, m, parent):
-        r'\['
-        parent.addToken(type=s)
-        # push to compute mode
-        parent.current.append(_COMPUTE_MODE)
-
     def t_lparen(self, s, m, parent):
         r'\('
         parent.addToken(type=parent.argsep)
