@@ -9,12 +9,12 @@ import glob
 import os
 import re
 import types
-from stsci.tools import basicpar, minmatch, irafutils, taskpars
-from stsci.tools.irafglobals import INDEF, Verbose, yes, no
-from stsci.tools.basicpar import (warning, _StringMixin, IrafPar, IrafParS,
+from .tools import minmatch, irafutils, taskpars, basicpar
+from .tools.irafglobals import INDEF, Verbose, yes, no
+from .tools.basicpar import (warning, _StringMixin, IrafPar, IrafParS,
                                   _cmdlineFlag)
 # also import basicpar.IrafPar* class names for cached scripts
-from stsci.tools.basicpar import (IrafParB, IrafParI, IrafParR, IrafParAB,
+from .tools.basicpar import (IrafParB, IrafParI, IrafParR, IrafParAB,
                                   IrafParAI, IrafParAR, IrafParAS)
 from . import iraf
 
@@ -306,7 +306,7 @@ class IrafParL(_StringMixin, IrafPar):
             # non-null value means we're reading from a file
             try:
                 if not self.fh:
-                    self.fh = open(iraf.Expand(self.value))
+                    self.fh = open(iraf.Expand(self.value), errors="ignore")
                     if self.fh.isatty():
                         self.lines = None
                     else:
@@ -909,7 +909,7 @@ class IrafParList(taskpars.TaskPars):
     def setParList(self, *args, **kw):
         """Set value of multiple parameters from list"""
         # first undo translations that were applied to keyword names
-        for key in kw.keys():
+        for key in list(kw.keys()):
             okey = key
             key = irafutils.untranslateName(key)
             if okey != key:
@@ -1312,9 +1312,8 @@ def _updateSpecialParFileDict(dirToCheck=None, strict=False):
     for supfname in flist:
         buf = []
         try:
-            supfile = open(supfname)
-            buf = supfile.readlines()
-            supfile.close()
+            with open(supfname, errors="ignore") as supfile:
+                buf = supfile.readlines()
         except OSError:
             pass
         if len(buf) < 1:
@@ -1465,9 +1464,8 @@ def _readpar(filename, strict=0):
 
     param_dict = {}
     param_list = []
-    fh = open(os.path.expanduser(filename))
-    lines = fh.readlines()
-    fh.close()
+    with open(os.path.expanduser(filename), errors="ignore") as fh:
+        lines = fh.readlines()
     # reverse order of lines so we can use pop method
     lines.reverse()
     while lines:
