@@ -32,10 +32,10 @@ import code
 import keyword
 import traceback
 import linecache
-from stsci.tools import capable, minmatch
 from . import iraf
 from . import irafinst
 from . import wutil
+from .tools import minmatch, capable
 from .pyrafglobals import pyrafDir
 
 
@@ -288,9 +288,6 @@ Set debugging flag.  If argument is omitted, default is 1 (debugging on.)
         except (ImportError, OSError):
             pass
 
-        # any irafinst tmp files?
-        irafinst.cleanup()  # any irafinst tmp files?
-
         # graphics
         wutil.closeGraphics()
 
